==> bamboo_1.2.orig.tar.gz: bamboo-1.2/decorators/editor/style.php <==
body {
	margin: 0px;
	padding: 0px;
	background: #ffffa9 url("<?= url('img/fadetop.png') ?>") top left repeat-x;
}
body, td, th, dd, dt, h1, h2, h3, h4, h5, h6, p, ol, ul, li, input {
  font-family: helvetica,arial,sans-serif;
}
body, td, td, p {font-size: 10pt;}

/* bamboo logo */
#logo {
	position: absolute;
	top: 0px;
	right: 0px; 
	height: 40;
	width: 180;
	background: url("<?= url('img/painted.png') ?>") top left no-repeat;
	z-index: 1;
}

#container {
	position: absolute;
	top:0px;
	left:0px;
	z-index: 10;
	height:100%;
	width:100%;
}

#leftcolumn {
	background: white;
	border-top: 1px solid black;
	border-right: 1px solid black;
	vertical-align: top;
	height:100%;
}

#spacecolumn {
	width: 4px;
	height: 110px;
}

#rightcolumn {
	background: white;
	border-top: 1px solid black;
	border-left: 1px solid black;
	vertical-align: top;
	padding: 10px;
}

hr {
	border: none;
	border-bottom: 1px solid #ccc;
	margin-top: 5px;
	margin-bottom: 5px;
	padding: 0px;
}
.thinhr {
	border: none;
	border-bottom: 1px dotted #ddd;
	margin: 0px;
	padding: 0px;
}

/*** navigation tree ***/

#navtree {
	font-size: 9pt;
	width: 150px;
	padding: 5px;
}
/*
#navtree ol {
	margin: 0px;
	padding: 0px;
}
#navtree li {
	margin: 0px;
	padding: 0px;
	text-indent: 0px;
	border: 0px solid #fff;
	list-style-type: none;
}
*/
#navtree div:hover {
	background: #ffc;
}
a.browser {
	display:block;
	text-decoration:none;
	padding-left: 16px;
	border: 1px solid #fff;
}
a.browser:hover {
	border: 1px solid #99F;
}

a.quick { /* "quick" is the little >> link menus beside each page */
	float: right;
	position: relative;
	top: -1.45em;
	left: 0px;
	text-decoration:none;
	padding: 1px;
}
a.quick:hover {
	border: 1px solid #99F;
	padding: 0px;
}

div#dropmenu {
	background-color: #ffc;
	border: 1px solid #99f;
}
div#dropmenu a {
	display: block;
	text-decoration:none;
	padding: 3px;	
}
div#dropmenu a:hover {background-color: #eeb;}
div#dropmenu div {color: #ccc; padding: 3px;}


a.type-dir {background: url("<?= url('img/small/folder.png') ?>") center left no-repeat;}
a.type-file {background: url("<?= url('img/small/file.png') ?>")  center left no-repeat;}
a.type-home {background: url("<?= url('img/small/home.png') ?>")  center left no-repeat;}
a.type-up {background: url("<?= url('img/triangle-up.png') ?>")  center left no-repeat;}
a.type-clip {background: url("<?= url('img/small/clip.png') ?>")  center left no-repeat;}
a.type-trash {background: url("<?= url('img/small/trash.png') ?>")  center left no-repeat;}

/**** tabs ****/

.tabs {
	position: relative;
	top: 5px;
}
.tabs table {
	padding: 0px;
	margin: 0px;
	border: 0px;
}
.tabs a {
	text-decoration: none;
	font-size: 10px;
}
.tabs td {
	border: 1px solid #000;
	padding: 3px 6px 3px 6px;
	background: #ddd;
	text-align: center;
}
.tabs td:hover {
	background: #ffc;
}
.tabs td.here {
	border-bottom: 1px solid #fff;
	background: #fff;
}

.button {
	font-size: 10px;
	background-color: #6AD;
	color: #fff;
	border: 1px solid #666;
	padding: 2px;
	text-decoration: none;
	
}

.button:hover {
	background-color: #9CF;
}

.textinput {
	border-width: 1px;
	background: #ffc;
	border-color: #000;
}

#data {
	margin: 5px 0px 5px 0px;
	width: 100%;
}

.box {
	background-color: #ffc;
	border: 1px solid black;
	padding: 2px;
	margin-top: 1em;
}
.section {font-weight: bold;}
.roweven {background-color: #fff;}
.rowodd  {background-color: #eeb;}

.debug {
	background-image: url("<?= url('img/50white.png') ?>");
	position: absolute;
	right: 0px;
	bottom: 0px;
	margin: 4px;
	padding: 10px;
	border: 1px dashed red;
	z-index: 30;
	font-size: 9px;
}

.subdebug {
	float: right;
	clear: both;
	border: 1px dotted grey;
}

div#lang {
	position: absolute;
	bottom: 0px; left: 2em;
	z-index: 100;
}
div#lang select {font-size: 8pt;}

==> bamboo_1.3.orig.tar.gz: bamboo-1.3/decorators/editor/style.php <==
body {
	margin: 0px;
	padding: 0px;
	background: #ffffa9 url("<?= url('img/fadetop.png') ?>") top left repeat-x;
}
body, td, th, dd, dt, h1, h2, h3, h4, h5, h6, p, ol, ul, li, input {
  font-family: helvetica,arial,sans-serif;
}
body, td, td, p {font-size: 10pt;}

/* bamboo logo */
#logo {
	position: absolute;
	top: 0px;
	right: 0px; 
	height: 40;
	width: 180;
	background: url("<?= url('img/painted.png') ?>") top left no-repeat;
	z-index: 1;
}

#container {
	position: absolute;
	top:0px;
	left:0px;
	z-index: 10;
	height:100%;
	width:100%;
}

#leftcolumn {
	background: white;
	border-top: 1px solid black;
	border-right: 1px solid black;
	vertical-align: top;
	height:100%;
}

#spacecolumn {
	width: 4px;
	height: 110px;
}

#rightcolumn {
	background: white;
	border-top: 1px solid black;
	border-left: 1px solid black;
	vertical-align: top;
	padding: 10px;
}

hr {
	border: none;
	border-bottom: 1px solid #ccc;
	margin-top: 5px;
	margin-bottom: 5px;
	padding: 0px;
}
.thinhr {
	border: none;
	border-bottom: 1px dotted #ddd;
	margin: 0px;
	padding: 0px;
}

/*** navigation tree ***/

#navtree {
	font-size: 9pt;
	width: 150px;
	padding: 5px;
}
/*
#navtree ol {
	margin: 0px;
	padding: 0px;
}
#navtree li {
	margin: 0px;
	padding: 0px;
	text-indent: 0px;
	border: 0px solid #fff;
	list-style-type: none;
}
*/
#navtree div:hover {
	background: #ffc;
}
a.browser {
	display:block;
	text-decoration:none;
	padding-left: 16px;
	border: 1px solid #fff;
}
a.browser:hover {
	border: 1px solid #99F;
}

a.quick { /* "quick" is the little >> link menus beside each page */
	float: right;
	position: relative;
	top: -1.45em;
	left: 0px;
	text-decoration:none;
	padding: 1px;
}
a.quick:hover {
	border: 1px solid #99F;
	padding: 0px;
}

div#dropmenu {
	background-color: #ffc;
	border: 1px solid #99f;
}
div#dropmenu a {
	display: block;
	text-decoration:none;
	padding: 3px;	
}
div#dropmenu a:hover {background-color: #eeb;}
div#dropmenu div {color: #ccc; padding: 3px;}


a.type-dir {background: url("<?= url('img/small/folder.png') ?>") center left no-repeat;}
a.type-file {background: url("<?= url('img/small/file.png') ?>")  center left no-repeat;}
a.type-home {background: url("<?= url('img/small/home.png') ?>")  center left no-repeat;}
a.type-up {background: url("<?= url('img/triangle-up.png') ?>")  center left no-repeat;}
a.type-clip {background: url("<?= url('img/small/clip.png') ?>")  center left no-repeat;}
a.type-trash {background: url("<?= url('img/small/trash.png') ?>")  center left no-repeat;}

/**** tabs ****/

.tabs {
	position: relative;
	top: 5px;
}
.tabs table {
	padding: 0px;
	margin: 0px;
	border: 0px;
}
.tabs a {
	text-decoration: none;
	font-size: 10px;
}
.tabs td {
	border: 1px solid #000;
	padding: 3px 6px 3px 6px;
	background: #ddd;
	text-align: center;
}
.tabs td:hover {
	background: #ffc;
}
.tabs td.here {
	border-bottom: 1px solid #fff;
	background: #fff;
}

.button {
	font-size: 10px;
	background-color: #6AD;
	color: #fff;
	border: 1px solid #666;
	padding: 2px;
	text-decoration: none;
	
}

.button:hover {
	background-color: #9CF;
}

.textinput {
	border-width: 1px;
	background: #ffc;
	border-color: #000;
}

#data {
	margin: 5px 0px 5px 0px;
	width: 100%;
}

.box {
	background-color: #ffc;
	border: 1px solid black;
	padding: 2px;
	margin-top: 1em;
}
.section {font-weight: bold;}
.roweven {background-color: #fff;}
.rowodd  {background-color: #eeb;}

.debug {
	background-image: url("<?= url('img/50white.png') ?>");
	position: absolute;
	right: 0px;
	bottom: 0px;
	margin: 4px;
	padding: 10px;
	border: 1px dashed red;
	z-index: 30;
	font-size: 9px;
}

.subdebug {
	float: right;
	clear: both;
	border: 1px dotted grey;
}

div#lang {
	position: absolute;
	bottom: 0px; left: 2em;
	z-index: 100;
}
div#lang select {font-size: 8pt;}

div.lang {
   margin-bottom: 0px;
   text-align: center;
}
div.lang a {
   position: relative;
   color: #996; 
   padding: 5px;
   text-decoration: none;
   border: 1px solid #fff;
}
div.lang a:hover {
   background: #ffc;
   border: 1px solid #eeb;
}
div.lang a.selected {
   background: #eeb;
   border: 1px solid #cc9;
   font-weight: normal;
}
div.lang a.old {
   font-style: italic;
}
div.lang a span {
	display: none;
}
div.lang a:hover span {
	display: block;
	position: absolute;
	top: 2em;
	left: 0;
}
